summaryrefslogtreecommitdiff
path: root/var
diff options
context:
space:
mode:
authorSeth R. Johnson <johnsonsr@ornl.gov>2021-08-15 08:59:19 -0400
committerGitHub <noreply@github.com>2021-08-15 07:59:19 -0500
commit2965c501a5fa7937b78794d01ed3603444cb8d36 (patch)
tree0691661682ca6447f75ea81898ced0947b0e0ee2 /var
parent8d881cb7eef8e90a8a2ae2f3d9c0ee0ee7dff02a (diff)
downloadspack-2965c501a5fa7937b78794d01ed3603444cb8d36.tar.gz
spack-2965c501a5fa7937b78794d01ed3603444cb8d36.tar.bz2
spack-2965c501a5fa7937b78794d01ed3603444cb8d36.tar.xz
spack-2965c501a5fa7937b78794d01ed3603444cb8d36.zip
openpbs: add provider, new version, new name (#25429)
Diffstat (limited to 'var')
-rw-r--r--var/spack/repos/builtin/packages/openpbs/package.py14
1 files changed, 8 insertions, 6 deletions
diff --git a/var/spack/repos/builtin/packages/openpbs/package.py b/var/spack/repos/builtin/packages/openpbs/package.py
index f12685ef88..7a45467d13 100644
--- a/var/spack/repos/builtin/packages/openpbs/package.py
+++ b/var/spack/repos/builtin/packages/openpbs/package.py
@@ -9,17 +9,15 @@ from spack import *
class Openpbs(AutotoolsPackage):
"""PBS Professional software optimizes job scheduling and workload
management in high-performance computing (HPC) environments - clusters,
clouds, and supercomputers - improving system efficiency and people's
productivity."""
- # TODO: update the description and the homepage url once the renaming is
- # finished: http://community.pbspro.org/t/openpbs-and-version-20-0/2075
-
- homepage = "https://www.pbspro.org"
+ homepage = "https://www.openpbs.org"
url = "https://github.com/openpbs/openpbs/archive/v19.1.3.tar.gz"
+ version('20.0.1', sha256='685a4abcea92bf518df02b544d25e237ae8cef76f86525f7bf3554812e9f50fa')
version('19.1.3', sha256='6e9d2614f839ff3d91d0ace3de04752b7c075da60c72fe6def76437aa05c9857')
depends_on('autoconf', type='build')
@@ -33,7 +31,8 @@ class Openpbs(AutotoolsPackage):
depends_on('ssmtp', type=('build', 'run'))
depends_on('xauth', type=('build', 'run'))
- depends_on('python@2.6:2.7', type=('build', 'link', 'run'))
+ depends_on('python@3.5:3.9', type=('build', 'link', 'run'), when='@20:')
+ depends_on('python@2.6:2.7', type=('build', 'link', 'run'), when='@:19')
depends_on('libx11')
depends_on('libice')
@@ -64,6 +63,9 @@ class Openpbs(AutotoolsPackage):
# Link to the dynamic library of Python instead of the static one.
patch('python.patch')
+ # Provides PBS functionality
+ provides('pbs')
+
def autoreconf(self, spec, prefix):
Executable('./autogen.sh')()
@@ -9,17 +9,15 @@ from spack import *
class Openpbs(AutotoolsPackage):
- """PBS Professional software optimizes job scheduling and workload
+ """OpenPBS software optimizes job scheduling and workload
management in high-performance computing (HPC) environments - clusters,
clouds, and supercomputers - improving system efficiency and people's